@@ -54,7 +54,7 @@ style_tabularray <- function(x,
   # convert to tabularray now that we've filled the bootstrap settings
   if (is.numeric(fontsize)) settings$tabularray <- sprintf("%s font=\\fontsize{%sem}{%sem}\\selectfont,", settings$tabularray, fontsize, fontsize + 0.3) 
   if (!is.null(align)) settings$tabularray <- sprintf("%s halign=%s,", settings$tabularray, align)
-  if (!is.null(width)) settings$tabularray <- sprintf("%s wd={%s},", settings$tabularray, width)
+  if (!is.null(width)) settings$tabularray <- sprintf("%s wd=%s,", settings$tabularray, width)
   if (indent > 0) settings$tabularary <- sprintf("%s preto={\\hspace{%sem}},", settings$tabularray, indent)
 
   vectorize_tabularray <- function(z) {
