@@ -1,9 +1,9 @@
-#' Style a Tiny Table in either LaTeX or HTML format
+#' Style a Tiny Table
 #'
 #' @details
-#' This function applies styling to a table created by `tt()`. It allows customization of text style (bold, italic, monospace), text and background colors, font size, cell width, text alignment, column span, and indentation. The function supports both LaTeX (tabularray) and HTML (bootstrap) formats.
+#' This function applies styling to a table created by `tt()`. It allows customization of text style (bold, italic, monospace), text and background colors, font size, cell width, text alignment, column span, and indentation. The function also supports passing native instructions to LaTeX (tabularray) and HTML (bootstrap) formats.
 #'
-#' Note that Markdown and Word formats are limited to these styles: italic, bold, strikeout.
+#' Warning: Markdown and Word formats are limited to these styles: italic, bold, strikeout. This is because there is no markdown syntax for the other options, and because we create Word documents by converting a markdown table to .docx via the Pandoc software.
 #'
 #' @param x A table object created by `tt()`.
 #' @param i Row indices where the styling should be applied. Can be a single value or a vector. `i=0` is the header, and negative values are higher level headers. If `colspan` is used, `i` must be of length 1.
@@ -24,7 +24,7 @@
 #'   - Color names with luminance levels from [the `ninecolors` package](https://mirror.quantum5.ca/CTAN/macros/latex/contrib/ninecolors/ninecolors.pdf) (ex: "azure4", "magenta8", "teal2", "gray1", "olive3"). 
 #' @param background Background color. Specified as a color name or hexadecimal code. Can be `NULL` for default color.
 #' @param fontsize Font size in em units. Can be `NULL` for default size.
-#' @param width Width of the cell or column. Can be `NULL` for default width.
+#' @param width Width of column in em units. Can be `NULL` for default width.
 #' @param fontsize Integer Font size in pt units.
 #' @param align A single character or a string with a number of characters equal to the number of columns in `j`. Valid characters include 'c' (center), 'l' (left), or 'r' (right).
 #' @param colspan Number of columns a cell should span. Can only be used if both `i` and `j` are of length 1. Must be an integer greater than 1.
@@ -51,8 +51,8 @@
 #' x <- mtcars[1:5, 1:5]
 #' tab <- tt(x)
 #' tab <- style_tt(tab, j = 1:5, align = "lcccr")
-#' tab <- style_tt(tab, i = 2:3,
-#'  background = "black", color = "orange", bold = TRUE)
+#' tab <- style_tt(tab, i = 2:3, background = "black", color = "orange", bold = TRUE)
+#' tab
 #'
 style_tt <- function (x,
                       i = NULL,
@@ -143,7 +143,7 @@ style_tt_lazy <- function (x,
 
   # sanity x
   if (is.null(meta(x))) stop("`x` must be generated by `tinytable::tt()`.", call. = FALSE)
-  if (!isTRUE(meta(x)$output %in% c("html", "latex", "markdown"))) return(x)
+  if (!isTRUE(meta(x)$output %in% c("html", "latex", "markdown", "typst"))) return(x)
 
   out <- x
 
@@ -190,6 +190,10 @@ style_tt_lazy <- function (x,
     tabularray_inner = tabularray_inner, tabularray_outer = tabularray_outer, bootstrap_css = bootstrap_css,
     bootstrap_css_rule = bootstrap_css_rule, bootstrap_class = bootstrap_class)
 
+  if (!is.null(width)) {
+    width <- paste0(width, "em")
+  }
+
   out <- style_tabularray(
     x = out, i = i, j = j, bold = bold, italic = italic, monospace = monospace, underline = underline, strikeout = strikeout,
     color = color, background = background, fontsize = fontsize, width = width, align = align, colspan = colspan, indent = indent,
@@ -208,6 +212,12 @@ style_tt_lazy <- function (x,
     bootstrap_css = bootstrap_css, bootstrap_css_rule = bootstrap_css_rule,
     line = line, line_color = line_color, line_width = line_width)
 
+  out <- style_typst(
+    x = out, i = i, j = j, bold = bold, italic = italic, monospace = monospace, underline = underline, strikeout = strikeout,
+    color = color, background = background, fontsize = fontsize, width = width, align = align, colspan = colspan, indent = indent,
+    bootstrap_css = bootstrap_css, bootstrap_css_rule = bootstrap_css_rule,
+    line = line, line_color = line_color, line_width = line_width)
+
   return(out)
 }
 
@@ -238,8 +248,13 @@ assert_style_tt <- function (x,
 
   m <- meta(x)
 
+  if (!is.null(width) && !is.null(i)) {
+    msg <- "The `width` argument cannot be used with `i`."
+    stop(msg, call. = FALSE)
+  }
+
   assert_integerish(colspan, len = 1, lower = 1, null.ok = TRUE)
-  assert_string(width, null.ok = TRUE)
+  assert_numeric(width, len = 1, lower = 0, null.ok = TRUE)
   assert_numeric(indent, len = 1, lower = 0)
   assert_character(background, null.ok = TRUE)
   assert_character(color, null.ok = TRUE)
